﻿<?php
// セッション開始
session_start();

// 共通関数・定数読み込み
require_once __DIR__ . '/functions.php';

// ID取得
$id = isset($_SESSION['change']['id']) ? $_SESSION['change']['id'] : NULL;

// ID確認
$idError = [];
if ($id === NULL) {
  $idError[] = 'IDが存在しません';
} else {
  // DB処理
  // SQL文に変動値がない場合:query
  // SQL文に変動値がある場合:prepare⇒bindValue⇒execute
  $dbError = [];
  try {
    $pdo = new PDO(DB_NAME, DB_USER, DB_PASS);

    // 値取得
    $item    = isset($_POST['item'])    ? $_POST['item']    : NULL;
    $price   = isset($_POST['price'])   ? $_POST['price']   : NULL;
    $stock   = isset($_POST['stock'])   ? $_POST['stock']   : NULL;
    $keyword = isset($_POST['keyword']) ? $_POST['keyword'] : NULL;
    $maker   = isset($_POST['maker'])   ? $_POST['maker']   : NULL;

    $item    = mb_convert_kana($item, 's');
    $price   = mb_convert_kana($price, 'sn');
    $stock   = mb_convert_kana($stock, 'sn');
    $keyword = mb_convert_kana($keyword, 's');
    $maker   = mb_convert_kana($maker, 's');

    $item    = trim($item);
    $price   = trim($price);
    $stock   = trim($stock);
    $keyword = trim($keyword);
    $maker   = trim($maker);

    // 値チェック
    $valError = [];

    $checkName = '商品名';
    $limit = 10;
    if (mb_strlen($item) > 0) {
      if (mb_strlen($item) > $limit) {
        $valError[] = "{$checkName}は{$limit}文字以内で入力してください";
      }
    } else {
      $valError[] = "{$checkName}を入力してください";
    }

    $checkName = '価格';
    $min = 0;
    $max = 100000000;
    if (mb_strlen($price) > 0) {
      if (ctype_digit($price)) {
        if ($price < $min || $price > $max) {
          $valError[] = "{$checkName}は{$min}以上{$max}以下で入力してください";
        }
      } else {
        $valError[] = "{$checkName}は数値で入力してください";
      }
    } else {
      $valError[] = "{$checkName}を入力してください";
    }

    $checkName = '在庫';
    $min = 0;
    $max = 10000;
    if (mb_strlen($stock) > 0) {
      if (ctype_digit($stock)) {
        if ($stock < $min || $stock > $max) {
          $valError[] = "{$checkName}は{$min}以上{$max}以下で入力してください";
        }
      } else {
        $valError[] = "{$checkName}は数値で入力してください";
      }
    }

    $makerName = '';
    $checkName = 'メーカー';
    if (mb_strlen($maker) > 0) {
      if (ctype_digit($maker)) {
        $sqlMaker = 'SELECT * FROM trader WHERE m_id=:maker';
        $stmtMaker = $pdo->prepare($sqlMaker);
        $stmtMaker->bindParam(':maker', $maker, PDO::PARAM_INT);
        $stmtMaker->execute();
        $countMaker = $stmtMaker->rowCount();
        if ($countMaker === 1) {
          $makerData = $stmtMaker->fetch(PDO::FETCH_ASSOC);
          $makerName = $makerData['company'];
        } else {
          $valError[] = "選択した{$checkName}が存在しません";
        }
      } else {
        $valError[] = "{$checkName}は不正な値です";
      }
    } else {
      $valError[] = "{$checkName}を選択してください";
    }

    // メーカー選択用データ取得
    if (count($valError) > 0) {
      $sqlTrader = 'SELECT * FROM trader';
      $stmtTrader = $pdo->query($sqlTrader);
      $countTrader = $stmtTrader->rowCount();
    }
  } catch (PDOException $e) {
    $dbError[] = $e->getMessage();
  } finally {
    $pdo = null;
  }
}

// デバッグ
if (false) {
  // SESSION
  d($_SESSION, '$_SESSION');
  // POST
  d($_POST, '$_POST');
  // ID
  d($idError, '$idError');
  d($id, '$id');
  // DB
  d($dbError, '$dbError');
  // 値
  d($valError, '$valError');
  d($item, '$item');
  d($price, '$price');
  d($stock, '$stock');
  d($keyword, '$keyword');
  d($maker, '$maker');
  // メーカー確認
  d($sqlMaker, '$sqlMaker');
  d($stmtMaker, '$stmtMaker');
  d($countMaker, '$countMaker');
  // メーカー選択
  d($sqlTrader, '$sqlTrader');
  d($stmtTrader, '$stmtTrader');
  d($countTrader, '$countTrader');
  // exit();
}

// ビューファイル選択
if (count($idError) > 0) {
  $error = $idError;
  require __DIR__ . '/view/_error.php';
} else {
  if (count($dbError) > 0) {
    $error = 'DBエラーが発生しました。';
    require __DIR__ . '/view/_error.php';
  } else {
    if (count($valError) > 0) {
      require __DIR__ . '/view/_change01.php';
    } else {
      $_SESSION['change']['item']    = $item;
      $_SESSION['change']['price']   = $price;
      $_SESSION['change']['stock']   = $stock;
      $_SESSION['change']['keyword'] = $keyword;
      $_SESSION['change']['maker']   = $maker;
      require __DIR__ . '/view/_change02.php';
    }
  }
}
