<?php

/**
 * 使用ファイル
 * view/_index10.php
 * view/parts/_Search10.php
 * view/parts/_Pagination10.php
 */

// セッション開始
session_start();
unset($_SESSION['add']);
unset($_SESSION['change']);
unset($_SESSION['delete']);

// 共通関数・定数読み込み
require_once __DIR__ . '/functions.php';

// DB処理
$dbError = [];
try {
  $pdo = new PDO(DB_NAME, DB_USER, DB_PASS);

  /**
   * 検索機能
   */
  // 検索用メーカーデータ取得
  $sqlTrader = 'SELECT * FROM trader';
  $stmtTrader = $pdo->query($sqlTrader);
  $countTrader = $stmtTrader->rowCount();

  // 検索値
  $searchStock = isset($_GET['searchStock']) ? $_GET['searchStock'] : '0';
  $searchMaker = isset($_GET['searchMaker']) ? $_GET['searchMaker'] : '0';

  // 検索SQL用配列作成
  $search = [];
  if ($searchStock !== '0') {
    $search['searchStock'] = " stationery.stock > 0";
  }
  if ($searchMaker !== '0') {
    $search['searchMaker'] = " stationery.maker=:searchMaker";
  }

  // 検索SQL用配列からWHEREプレースホルダー作成
  $where = '';
  if (count($search) > 0) {
    $where .= ' WHERE' . implode(' AND', $search);
  }

  /**
   * ページネーション
   */
  // 現在のページ番号を取得
  $page = isset($_GET['page']) ? $_GET['page'] : 1;
  if (!ctype_digit($page)) {
    $page = 1;
  }

  // 1ページに表示する件数を設定
  $displayResults = 5;

  // LIMIT文の開始番号を計算
  $start = ($page - 1) * $displayResults;

  // 総件数取得
  $sqlTotal = 'SELECT COUNT(id) as count FROM stationery' . $where;
  $stmtTotal = $pdo->prepare($sqlTotal);
  if (isset($search['searchMaker'])) {
    $stmtTotal->bindParam(':searchMaker', $searchMaker, PDO::PARAM_INT);
  }
  $stmtTotal->execute();
  $total = $stmtTotal->fetchColumn();

  // ページネーション用LIMITプレースホルダー作成
  $limit = ' LIMIT :start, :displayResults';


  $sqlStationery = 'SELECT * FROM stationery LEFT JOIN trader ON stationery.maker=trader.m_id' . $where . $limit;
  $stmtStationery = $pdo->prepare($sqlStationery);
  if (isset($search['searchMaker'])) {
    $stmtStationery->bindParam(':searchMaker', $searchMaker, PDO::PARAM_INT);
  }
  $stmtStationery->bindParam(':start', $start, PDO::PARAM_INT);
  $stmtStationery->bindParam(':displayResults', $displayResults, PDO::PARAM_INT);

  $stmtStationery->execute();
  $countStationery = $stmtStationery->rowCount();
} catch (PDOException $e) {
  $dbError[] = $e->getMessage();
} finally {
  $pdo = null;
}

// デバッグ
if (false) {
  // SESSION
  d($_SESSION, '$_SESSION');
  // GET
  d($_GET, '$_GET');
  // DB
  d($dbError, '$dbError');
  // メーカー
  d($sqlTrader, '$sqlTrader');
  d($stmtTrader, '$stmtTrader');
  d($countTrader, '$countTrader');
  // 検索
  d($searchStock, '$searchStock');
  d($searchMaker, '$searchMaker');
  d($search, '$search');
  d($where, '$where');
  // ページネーション
  d($page, '$page');
  d($displayResults, '$displayResults');
  d($sqlTotal, '$sqlTotal');
  d($stmtTotal, '$stmtTotal');
  d($total, '$total');
  d($limit, '$limit');
  // 一覧取得
  d($sqlStationery, '$sqlStationery');
  d($stmtStationery, '$stmtStationery');
  d($countStationery, '$countStationery');
  // exit();
}

// ビューファイル選択
if (count($dbError) > 0) {
  $error = 'DBエラーが発生しました。';
  require __DIR__ . '/view/_error.php';
} else {
  require __DIR__ . '/view/_index10.php';
}
